#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path-io
version:              1.8.2
visibility:           public
id:                   path-io-1.8.2-J3oPz6svUjz5wY9ouZNltz
key:                  path-io-1.8.2-J3oPz6svUjz5wY9ouZNltz
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  6eb678d5eaa634378465f56a50b24368
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-9.6.6/site-local/path-io-1.8.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/path-io-1.8.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/path-io-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path-io
hs-libraries:         HSpath-io-1.8.2-J3oPz6svUjz5wY9ouZNltz
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO exceptions-0.10.7
    filepath-1.4.300.1 path-0.9.6-CG6breuY1qpGvStm5q67Gc
    temporary-1.3-7FXkQQKerYU7UfmRyKNwo9 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-DqDzbwuaouv1yXLtKQLq3q

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

